@@ -49,11 +49,11 @@ class Handlers:
         if not auth:
             return web.Response(status=401)
 
-        filters = ["qps", "domains", "clients", "query/bytes", "response/bytes",
-                   "query", "query/udp", "query/tcp", "query/inet", "query/inet6", 
+        filters = ["pps", "domains", "clients", "query/bytes", "response/bytes",
+                   "qps", "query", "query/udp", "query/tcp", "query/inet", "query/inet6", 
                    "query/a", "query/aaaa", "query/svr",
-                   "response", "response/udp", "response/tcp", "response/inet", "response/inet6", 
-                   "response/nxdomain", "response/noerror", "response/serverfail",
+                   "rps", "response", "response/udp", "response/tcp", "response/inet", "response/inet6", 
+                   "response/nxdomain", "response/noerror", "response/servfail", "response/refused",
                    "response/latency0_1", "response/latency1_10", "response/latency10_50",
                    "response/latency50_100", "response/latency100_1000", "response/latency_slow"]
                    
@@ -72,10 +72,18 @@ class Handlers:
         p.append( "# TYPE dnstap_responses_bytes_total counter" )
         p.append( "dnstap_responses_bytes_total %s" % counters["response/bytes"] )
         
+        p.append( "# HELP dnstap_pps Number of packets per second received" )
+        p.append( "# TYPE dnstap_pps gauge" )
+        p.append( "dnstap_pps %s" % counters["pps"] )
+        
         p.append( "# HELP dnstap_qps Number of queries per second received" )
         p.append( "# TYPE dnstap_qps gauge" )
         p.append( "dnstap_qps %s" % counters["qps"] )
         
+        p.append( "# HELP dnstap_rps Number of responses per second received" )
+        p.append( "# TYPE dnstap_rps gauge" )
+        p.append( "dnstap_rps %s" % counters["rps"] )
+        
         p.append( "# HELP dnstap_domains Number of domains asked" )
         p.append( "# TYPE dnstap_domains counter" )
         p.append( "dnstap_domains %s" % counters["domains"] )
@@ -140,14 +148,18 @@ class Handlers:
         p.append( "# TYPE dnstap_responses_noerror counter" )
         p.append( "dnstap_responses_noerror %s" % counters["response/noerror"] )
         
-        p.append( "# HELP dnstap_responses_nxdomain Number of NXDomain answers" )
+        p.append( "# HELP dnstap_responses_nxdomain Number of NXDOMAIN answers" )
         p.append( "# TYPE dnstap_responses_nxdomain counter" )
         p.append( "dnstap_responses_nxdomain %s" % counters["response/nxdomain"] )
         
-        p.append( "# HELP dnstap_responses_serverfail Number of SERVFAIL answers" )
-        p.append( "# TYPE dnstap_responses_serverfail counter" )
-        p.append( "dnstap_responses_serverfail %s" % counters["response/serverfail"] )
+        p.append( "# HELP dnstap_responses_servfail Number of SERVFAIL answers" )
+        p.append( "# TYPE dnstap_responses_servfail counter" )
+        p.append( "dnstap_responses_servfail %s" % counters["response/servfail"] )
 
+        p.append( "# HELP dnstap_responses_refused Number of REFUSED answers" )
+        p.append( "# TYPE dnstap_responses_refused counter" )
+        p.append( "dnstap_responses_refused %s" % counters["response/refused"] )
+        
         p.append( "# HELP dnstap_latency0_1 Number of queries answered in less than 1ms" )
         p.append( "# TYPE dnstap_latency0_1 counter" )
         p.append( "dnstap_latency0_1 %s" % counters["response/latency0_1"] )
@@ -181,9 +193,15 @@ class Handlers:
             p.append( "# HELP dnstap_responses_bytes_total Total number of bytes for responses of this dnstap identity" )
             p.append( "# TYPE dnstap_responses_bytes_total counter" )
         
+            p.append( "# HELP dnstap_pps Number of packets per second for this dnstap identity" )
+            p.append( "# TYPE dnstap_pps gauge" )
+            
             p.append( "# HELP dnstap_qps Number of queries per second for this dnstap identity" )
             p.append( "# TYPE dnstap_qps gauge" )
             
+            p.append( "# HELP dnstap_rps Number of responses per second for this dnstap identity" )
+            p.append( "# TYPE dnstap_rps gauge" )
+            
             p.append( "# HELP dnstap_domains Number of domains asked for this dnstap identity" )
             p.append( "# TYPE dnstap_domains counter" )
         
@@ -238,6 +256,8 @@ class Handlers:
             p.append( "# HELP dnstap_responses_serverfail Number of SERVFAIL answers for this dnstap identity" )
             p.append( "# TYPE dnstap_responses_serverfail counter" )
             
+            p.append( "# HELP dnstap_responses_refused Number of REFUSED answers for this dnstap identity" )
+            p.append( "# TYPE dnstap_responses_refused counter" )
         
             p.append( "# HELP dnstap_latency1_10 Number of queries answered in 1-10 ms for this dnstap identity" )
             p.append( "# TYPE dnstap_latency1_10 counter" )
@@ -261,7 +281,9 @@ class Handlers:
             p.append( "dnstap_queries_bytes_total{identity=\"%s\"} %s" % (s,sub_cntrs["query/bytes"]) )
             p.append( "dnstap_responses_bytes_total{identity=\"%s\"} %s" % (s,sub_cntrs["response/bytes"]) )
             
+            p.append( "dnstap_pps{identity=\"%s\"} %s" % (s,sub_cntrs["pps"]) )
             p.append( "dnstap_qps{identity=\"%s\"} %s" % (s,sub_cntrs["qps"]) )
+            p.append( "dnstap_rps{identity=\"%s\"} %s" % (s,sub_cntrs["rps"]) )
             p.append( "dnstap_domains{identity=\"%s\"} %s" % (s,sub_cntrs["domains"]) )
             p.append( "dnstap_clients{identity=\"%s\"} %s" % (s,sub_cntrs["clients"]) )
             
@@ -281,8 +303,9 @@ class Handlers:
             p.append( "dnstap_response_inet6{identity=\"%s\"} %s" % (s,sub_cntrs["response/inet6"]) )
             p.append( "dnstap_responses_noerror{identity=\"%s\"} %s" % (s,sub_cntrs["response/noerror"]) )
             p.append( "dnstap_responses_nxdomain{identity=\"%s\"} %s" % (s,sub_cntrs["response/nxdomain"]) )
-            p.append( "dnstap_responses_serverfail{identity=\"%s\"} %s" % (s,sub_cntrs["response/serverfail"]) )
-
+            p.append( "dnstap_responses_servfail{identity=\"%s\"} %s" % (s,sub_cntrs["response/servfail"]) )
+            p.append( "dnstap_responses_refused{identity=\"%s\"} %s" % (s,sub_cntrs["response/refused"]) )
+            
             p.append( "dnstap_latency0_1{identity=\"%s\"} %s" % (s,sub_cntrs["response/latency0_1"]) )
             p.append( "dnstap_latency1_10{identity=\"%s\"} %s" % (s,sub_cntrs["response/latency1_10"]) )
             p.append( "dnstap_latency10_50{identity=\"%s\"} %s" % (s,sub_cntrs["response/latency10_50"]) )
@@ -358,7 +381,12 @@ async def create_server(loop, cfg, stats, cfg_stats):
 
     # create the server
     listen_address = (cfg["local-address"], cfg["local-port"])
-    srv = await loop.create_server(app.make_handler(access_log=None), *listen_address)
-    clogger.debug("Api rest: listening on %s:%s" % listen_address )
+    try:
+        srv = await loop.create_server(app.make_handler(access_log=None), *listen_address)
+    except OSError as e:
+        clogger.error( "http api: %s" % e)
+        return None
+        
+    clogger.debug("Webserver: listening on %s:%s" % listen_address )
     
     return srv
